/*******************************************************************************
* File Name: ShiftReg_H_PM.c
* Version 2.30
*
* Description:
*  This file provides the API source code for sleep mode support for Shift
*  Register component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "ShiftReg_H.h"

static ShiftReg_H_BACKUP_STRUCT ShiftReg_H_backup =
{
    ShiftReg_H_DISABLED,

    ((uint16) ShiftReg_H_DEFAULT_A0),
    ((uint16) ShiftReg_H_DEFAULT_A1),

    #if(CY_UDB_V0)
        ((uint16) ShiftReg_H_INT_SRC),
    #endif /* (CY_UDB_V0) */
};


/*******************************************************************************
* Function Name: ShiftReg_H_SaveConfig
********************************************************************************
*
* Summary:
*  Saves Shift Register configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ShiftReg_H_SaveConfig(void) 
{
    /* Store working registers A0 and A1 */
    ShiftReg_H_backup.saveSrA0Reg   = CY_GET_REG16(ShiftReg_H_SHIFT_REG_LSB_PTR);
    ShiftReg_H_backup.saveSrA1Reg   = CY_GET_REG16(ShiftReg_H_SHIFT_REG_VALUE_LSB_PTR);

    #if(CY_UDB_V0)
        ShiftReg_H_backup.saveSrIntMask = ShiftReg_H_SR_STATUS_MASK;
    #endif /* (CY_UDB_V0) */
}


/*******************************************************************************
* Function Name: ShiftReg_H_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores Shift Register configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ShiftReg_H_RestoreConfig(void) 
{
    /* Restore working registers A0 and A1 */
    CY_SET_REG16(ShiftReg_H_SHIFT_REG_LSB_PTR, ShiftReg_H_backup.saveSrA0Reg);
    CY_SET_REG16(ShiftReg_H_SHIFT_REG_VALUE_LSB_PTR, ShiftReg_H_backup.saveSrA1Reg);

    #if(CY_UDB_V0)
        ShiftReg_H_SR_STATUS_MASK = ((uint8) ShiftReg_H_backup.saveSrIntMask);
    #endif /* (CY_UDB_V0) */
}


/*******************************************************************************
* Function Name: ShiftReg_H_Sleep
********************************************************************************
*
* Summary:
*  Prepare the component to enter a Sleep mode.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void ShiftReg_H_Sleep(void) 
{
    ShiftReg_H_backup.enableState = ((uint8) ShiftReg_H_IS_ENABLED);

    ShiftReg_H_Stop();
    ShiftReg_H_SaveConfig();
}


/*******************************************************************************
* Function Name: ShiftReg_H_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void ShiftReg_H_Wakeup(void) 
{
    ShiftReg_H_RestoreConfig();

    if(0u != ShiftReg_H_backup.enableState)
    {
        ShiftReg_H_Enable();
    }
}


/* [] END OF FILE */
