/*******************************************************************************
* File Name: Vcc.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Vcc.h"


/*******************************************************************************
* Function Name: Vcc_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Vcc_Write(uint8 value) 
{
    uint8 staticBits = (Vcc_DR & (uint8)(~Vcc_MASK));
    Vcc_DR = staticBits | ((uint8)(value << Vcc_SHIFT) & Vcc_MASK);
}


/*******************************************************************************
* Function Name: Vcc_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Vcc_DM_STRONG     Strong Drive 
*  Vcc_DM_OD_HI      Open Drain, Drives High 
*  Vcc_DM_OD_LO      Open Drain, Drives Low 
*  Vcc_DM_RES_UP     Resistive Pull Up 
*  Vcc_DM_RES_DWN    Resistive Pull Down 
*  Vcc_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Vcc_DM_DIG_HIZ    High Impedance Digital 
*  Vcc_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Vcc_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Vcc_0, mode);
}


/*******************************************************************************
* Function Name: Vcc_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Vcc_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Vcc_Read(void) 
{
    return (Vcc_PS & Vcc_MASK) >> Vcc_SHIFT;
}


/*******************************************************************************
* Function Name: Vcc_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Vcc_ReadDataReg(void) 
{
    return (Vcc_DR & Vcc_MASK) >> Vcc_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Vcc_INTSTAT) 

    /*******************************************************************************
    * Function Name: Vcc_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Vcc_ClearInterrupt(void) 
    {
        return (Vcc_INTSTAT & Vcc_MASK) >> Vcc_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
